@@ -8,9 +8,9 @@ import polars._reexport as pl
 import polars.functions as F
 from polars._utils.async_ import _AioDataFrameResult, _GeventDataFrameResult
 from polars._utils.deprecation import (
-    deprecate_function,
     deprecate_renamed_parameter,
     deprecate_streaming_parameter,
+    deprecated,
     issue_deprecation_warning,
 )
 from polars._utils.parse import (
@@ -21,12 +21,16 @@ from polars._utils.unstable import issue_unstable_warning, unstable
 from polars._utils.various import extend_bool, qualified_type_name
 from polars._utils.wrap import wrap_df, wrap_expr
 from polars.datatypes import DTYPE_TEMPORAL_UNITS, Date, Datetime, Int64
-from polars.lazyframe.opt_flags import OptFlags
+from polars.lazyframe.opt_flags import (
+    DEFAULT_QUERY_OPT_FLAGS,
+    forward_old_opt_flags,
+)
 
 with contextlib.suppress(ImportError):  # Module not available when building docs
     import polars.polars as plr
 
 if TYPE_CHECKING:
+    import sys
     from collections.abc import Awaitable, Collection, Iterable
     from typing import Literal
 
@@ -37,8 +41,16 @@ if TYPE_CHECKING:
         EpochTimeUnit,
         IntoExpr,
         PolarsDataType,
-        RollingInterpolationMethod,
+        QuantileMethod,
     )
+    from polars.lazyframe.opt_flags import (
+        QueryOptFlags,
+    )
+
+    if sys.version_info >= (3, 13):
+        from warnings import deprecated
+    else:
+        from typing_extensions import deprecated  # noqa: TC004
 
 
 def field(name: str | list[str]) -> Expr:
@@ -55,7 +67,7 @@ def field(name: str | list[str]) -> Expr:
 
 def element() -> Expr:
     """
-    Alias for an element being evaluated in an `eval` expression.
+    Alias for an element being evaluated in an `eval` or `filter` expression.
 
     Examples
     --------
@@ -102,6 +114,24 @@ def element() -> Expr:
     │ 8   ┆ 5   ┆ [16, 10]    │
     │ 3   ┆ 2   ┆ [6, 4]      │
     └─────┴─────┴─────────────┘
+
+    A filter operation on list elements
+
+    >>> import polars as pl
+    >>> df = pl.DataFrame({"a": [1, 8, 3], "b": [4, 5, 2]})
+    >>> df.with_columns(
+    ...     evens=pl.concat_list("a", "b").list.filter(pl.element() % 2 == 0)
+    ... )
+    shape: (3, 3)
+    ┌─────┬─────┬───────────┐
+    │ a   ┆ b   ┆ evens     │
+    │ --- ┆ --- ┆ ---       │
+    │ i64 ┆ i64 ┆ list[i64] │
+    ╞═════╪═════╪═══════════╡
+    │ 1   ┆ 4   ┆ [4]       │
+    │ 8   ┆ 5   ┆ [8]       │
+    │ 3   ┆ 2   ┆ [2]       │
+    └─────┴─────┴───────────┘
     """
     return F.col("")
 
@@ -893,7 +923,7 @@ def corr(
     """
     if ddof is not None:
         issue_deprecation_warning(
-            "The `ddof` parameter has no effect. Do not use it.",
+            "the `ddof` parameter has no effect. Do not use it.",
             version="1.17.0",
         )
 
@@ -1510,7 +1540,7 @@ def arctan2(y: str | Expr, x: str | Expr) -> Expr:
     return wrap_expr(plr.arctan2(y._pyexpr, x._pyexpr))
 
 
-@deprecate_function("Use `arctan2` followed by `.degrees()` instead.", version="1.0.0")
+@deprecated("`arctan2d` is deprecated; use `arctan2` followed by `.degrees()` instead.")
 def arctan2d(y: str | Expr, x: str | Expr) -> Expr:
     """
     Compute two argument arctan in degrees.
@@ -1637,7 +1667,7 @@ def groups(column: str) -> Expr:
 def quantile(
     column: str,
     quantile: float | Expr,
-    interpolation: RollingInterpolationMethod = "nearest",
+    interpolation: QuantileMethod = "nearest",
 ) -> Expr:
     """
     Syntactic sugar for `pl.col("foo").quantile(..)`.
@@ -1648,7 +1678,7 @@ def quantile(
         Column name.
     quantile
         Quantile between 0.0 and 1.0.
-    interpolation : {'nearest', 'higher', 'lower', 'midpoint', 'linear'}
+    interpolation : {'nearest', 'higher', 'lower', 'midpoint', 'linear', 'equiprobable'}
         Interpolation method.
     """
     return F.col(column).quantile(quantile, interpolation)
@@ -1751,11 +1781,11 @@ def arg_sort_by(
 
 
 @deprecate_streaming_parameter()
+@forward_old_opt_flags()
 def collect_all(
     lazy_frames: Iterable[LazyFrame],
     *,
     type_coercion: bool = True,
-    _type_check: bool = True,
     predicate_pushdown: bool = True,
     projection_pushdown: bool = True,
     simplify_expression: bool = True,
@@ -1765,7 +1795,7 @@ def collect_all(
     comm_subexpr_elim: bool = True,
     cluster_with_columns: bool = True,
     collapse_joins: bool = True,
-    _check_order: bool = True,
+    optimizations: QueryOptFlags = DEFAULT_QUERY_OPT_FLAGS,
     engine: EngineType = "auto",
 ) -> list[DataFrame]:
     """
@@ -1782,24 +1812,60 @@ def collect_all(
         A list of LazyFrames to collect.
     type_coercion
         Do type coercion optimization.
+
+        .. deprecated:: 1.30.0
+            Use the `optimizations` parameters.
     predicate_pushdown
         Do predicate pushdown optimization.
+
+        .. deprecated:: 1.30.0
+            Use the `optimizations` parameters.
     projection_pushdown
         Do projection pushdown optimization.
+
+        .. deprecated:: 1.30.0
+            Use the `optimizations` parameters.
     simplify_expression
         Run simplify expressions optimization.
+
+        .. deprecated:: 1.30.0
+            Use the `optimizations` parameters.
     no_optimization
         Turn off optimizations.
+
+        .. deprecated:: 1.30.0
+            Use the `optimizations` parameters.
     slice_pushdown
         Slice pushdown optimization.
+
+        .. deprecated:: 1.30.0
+            Use the `optimizations` parameters.
     comm_subplan_elim
         Will try to cache branching subplans that occur on self-joins or unions.
+
+        .. deprecated:: 1.30.0
+            Use the `optimizations` parameters.
     comm_subexpr_elim
         Common subexpressions will be cached and reused.
+
+        .. deprecated:: 1.30.0
+            Use the `optimizations` parameters.
     cluster_with_columns
         Combine sequential independent calls to with_columns
+
+        .. deprecated:: 1.30.0
+            Use the `optimizations` parameters.
     collapse_joins
         Collapse a join and filters into a faster join
+
+        .. deprecated:: 1.30.0
+            Use the `optimizations` parameters.
+    optimizations
+        The optimization passes done during query optimization.
+
+        .. warning::
+            This functionality is considered **unstable**. It may be changed
+            at any point without it being considered a breaking change.
     engine
         Select the engine used to process the query, optional.
         At the moment, if set to `"auto"` (default), the query
@@ -1819,27 +1885,11 @@ def collect_all(
         The collected DataFrames, returned in the same order as the input LazyFrames.
 
     """
-    optflags = OptFlags(
-        _type_coercion=type_coercion,
-        _type_check=_type_check,
-        predicate_pushdown=predicate_pushdown,
-        projection_pushdown=projection_pushdown,
-        simplify_expression=simplify_expression,
-        slice_pushdown=slice_pushdown,
-        comm_subplan_elim=comm_subplan_elim,
-        comm_subexpr_elim=comm_subexpr_elim,
-        cluster_with_columns=cluster_with_columns,
-        collapse_joins=collapse_joins,
-        check_order_observe=_check_order,
-    )
-    if no_optimization:
-        optflags.no_optimizations()
-
     if engine in ("streaming", "old-streaming"):
-        issue_unstable_warning("Streaming mode is considered unstable.")
+        issue_unstable_warning("streaming mode is considered unstable.")
 
     lfs = [lf._ldf for lf in lazy_frames]
-    out = plr.collect_all(lfs, engine, optflags._pyoptflags)
+    out = plr.collect_all(lfs, engine, optimizations._pyoptflags)
 
     # wrap the pydataframes into dataframe
     result = [wrap_df(pydf) for pydf in out]
@@ -1852,18 +1902,8 @@ def collect_all_async(
     lazy_frames: Iterable[LazyFrame],
     *,
     gevent: Literal[True],
-    type_coercion: bool = True,
-    _type_check: bool = True,
-    predicate_pushdown: bool = True,
-    projection_pushdown: bool = True,
-    simplify_expression: bool = True,
-    no_optimization: bool = True,
-    slice_pushdown: bool = True,
-    comm_subplan_elim: bool = True,
-    comm_subexpr_elim: bool = True,
-    cluster_with_columns: bool = True,
-    collapse_joins: bool = True,
     engine: EngineType = "auto",
+    optimizations: QueryOptFlags = DEFAULT_QUERY_OPT_FLAGS,
 ) -> _GeventDataFrameResult[list[DataFrame]]: ...
 
 
@@ -1872,18 +1912,8 @@ def collect_all_async(
     lazy_frames: Iterable[LazyFrame],
     *,
     gevent: Literal[False] = False,
-    type_coercion: bool = True,
-    _type_check: bool = True,
-    predicate_pushdown: bool = True,
-    projection_pushdown: bool = True,
-    simplify_expression: bool = True,
-    no_optimization: bool = False,
-    slice_pushdown: bool = True,
-    comm_subplan_elim: bool = True,
-    comm_subexpr_elim: bool = True,
-    cluster_with_columns: bool = True,
-    collapse_joins: bool = True,
     engine: EngineType = "auto",
+    optimizations: QueryOptFlags = DEFAULT_QUERY_OPT_FLAGS,
 ) -> Awaitable[list[DataFrame]]: ...
 
 
@@ -1893,19 +1923,8 @@ def collect_all_async(
     lazy_frames: Iterable[LazyFrame],
     *,
     gevent: bool = False,
-    type_coercion: bool = True,
-    _type_check: bool = True,
-    predicate_pushdown: bool = True,
-    projection_pushdown: bool = True,
-    simplify_expression: bool = True,
-    no_optimization: bool = False,
-    slice_pushdown: bool = True,
-    comm_subplan_elim: bool = True,
-    comm_subexpr_elim: bool = True,
-    cluster_with_columns: bool = True,
-    collapse_joins: bool = True,
-    _check_order: bool = True,
     engine: EngineType = "auto",
+    optimizations: QueryOptFlags = DEFAULT_QUERY_OPT_FLAGS,
 ) -> Awaitable[list[DataFrame]] | _GeventDataFrameResult[list[DataFrame]]:
     """
     Collect multiple LazyFrames at the same time asynchronously in thread pool.
@@ -1927,26 +1946,12 @@ def collect_all_async(
         A list of LazyFrames to collect.
     gevent
         Return wrapper to `gevent.event.AsyncResult` instead of Awaitable
-    type_coercion
-        Do type coercion optimization.
-    predicate_pushdown
-        Do predicate pushdown optimization.
-    projection_pushdown
-        Do projection pushdown optimization.
-    simplify_expression
-        Run simplify expressions optimization.
-    no_optimization
-        Turn off (certain) optimizations.
-    slice_pushdown
-        Slice pushdown optimization.
-    comm_subplan_elim
-        Will try to cache branching subplans that occur on self-joins or unions.
-    comm_subexpr_elim
-        Common subexpressions will be cached and reused.
-    cluster_with_columns
-        Combine sequential independent calls to with_columns
-    collapse_joins
-        Collapse a join and filters into a faster join
+    optimizations
+        The optimization passes done during query optimization.
+
+        .. warning::
+            This functionality is considered **unstable**. It may be changed
+            at any point without it being considered a breaking change.
     engine
         Select the engine used to process the query, optional.
         At the moment, if set to `"auto"` (default), the query
@@ -1977,31 +1982,15 @@ def collect_all_async(
     If `gevent=True` then returns wrapper that has
     `.get(block=True, timeout=None)` method.
     """
-    optflags = OptFlags(
-        _type_coercion=type_coercion,
-        _type_check=_type_check,
-        predicate_pushdown=predicate_pushdown,
-        projection_pushdown=projection_pushdown,
-        simplify_expression=simplify_expression,
-        slice_pushdown=slice_pushdown,
-        comm_subplan_elim=comm_subplan_elim,
-        comm_subexpr_elim=comm_subexpr_elim,
-        cluster_with_columns=cluster_with_columns,
-        collapse_joins=collapse_joins,
-        check_order_observe=_check_order,
-    )
-    if no_optimization:
-        optflags.no_optimizations()
-
     if engine in ("streaming", "old-streaming"):
-        issue_unstable_warning("Streaming mode is considered unstable.")
+        issue_unstable_warning("streaming mode is considered unstable.")
 
     result: (
         _GeventDataFrameResult[list[DataFrame]] | _AioDataFrameResult[list[DataFrame]]
     ) = _GeventDataFrameResult() if gevent else _AioDataFrameResult()
     lfs = [lf._ldf for lf in lazy_frames]
     plr.collect_all_with_callback(
-        lfs, engine, optflags._pyoptflags, result._callback_all
+        lfs, engine, optimizations._pyoptflags, result._callback_all
     )
     return result
 
@@ -2010,18 +1999,7 @@ def collect_all_async(
 def explain_all(
     lazy_frames: Iterable[LazyFrame],
     *,
-    type_coercion: bool = True,
-    _type_check: bool = True,
-    predicate_pushdown: bool = True,
-    projection_pushdown: bool = True,
-    simplify_expression: bool = True,
-    no_optimization: bool = False,
-    slice_pushdown: bool = True,
-    comm_subplan_elim: bool = True,
-    comm_subexpr_elim: bool = True,
-    cluster_with_columns: bool = True,
-    collapse_joins: bool = True,
-    _check_order: bool = True,
+    optimizations: QueryOptFlags = DEFAULT_QUERY_OPT_FLAGS,
 ) -> str:
     """
     Explain multiple LazyFrames as if passed to `collect_all`.
@@ -2033,49 +2011,19 @@ def explain_all(
     ----------
     lazy_frames
         A list of LazyFrames to collect.
-    type_coercion
-        Do type coercion optimization.
-    predicate_pushdown
-        Do predicate pushdown optimization.
-    projection_pushdown
-        Do projection pushdown optimization.
-    simplify_expression
-        Run simplify expressions optimization.
-    no_optimization
-        Turn off optimizations.
-    slice_pushdown
-        Slice pushdown optimization.
-    comm_subplan_elim
-        Will try to cache branching subplans that occur on self-joins or unions.
-    comm_subexpr_elim
-        Common subexpressions will be cached and reused.
-    cluster_with_columns
-        Combine sequential independent calls to with_columns
-    collapse_joins
-        Collapse a join and filters into a faster join
+    optimizations
+        The optimization passes done during query optimization.
+
+        .. warning::
+            This functionality is considered **unstable**. It may be changed
+            at any point without it being considered a breaking change.
 
     Returns
     -------
     Explained plan.
     """
-    optflags = OptFlags(
-        _type_coercion=type_coercion,
-        _type_check=_type_check,
-        predicate_pushdown=predicate_pushdown,
-        projection_pushdown=projection_pushdown,
-        simplify_expression=simplify_expression,
-        slice_pushdown=slice_pushdown,
-        comm_subplan_elim=comm_subplan_elim,
-        comm_subexpr_elim=comm_subexpr_elim,
-        cluster_with_columns=cluster_with_columns,
-        collapse_joins=collapse_joins,
-        check_order_observe=_check_order,
-    )
-    if no_optimization:
-        optflags.no_optimizations()
-
     lfs = [lf._ldf for lf in lazy_frames]
-    return plr.explain_all(lfs, optflags._pyoptflags)
+    return plr.explain_all(lfs, optimizations._pyoptflags)
 
 
 @overload
@@ -2400,6 +2348,9 @@ def rolling_cov(
     The window at a given row includes the row itself and the
     `window_size - 1` elements before it.
 
+    .. versionchanged:: 1.21.0
+        The `min_periods` parameter was renamed `min_samples`.
+
     Parameters
     ----------
     a
@@ -2441,6 +2392,9 @@ def rolling_corr(
     The window at a given row includes the row itself and the
     `window_size - 1` elements before it.
 
+    .. versionchanged:: 1.21.0
+        The `min_periods` parameter was renamed `min_samples`.
+
     Parameters
     ----------
     a
